Class: Google::Apis::RealtimebiddingV1::CreativeServingDecision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

Top level status and detected attributes of a creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeServingDecision

Returns a new instance of CreativeServingDecision.



801
802
803
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_technology_providersGoogle::Apis::RealtimebiddingV1::AdTechnologyProviders

The list of detected Ad Technology Providers for this creative. Bids placed for inventory that will serve to EEA or UK users are expected to comply with GDPR requirements. You must ensure that the creatives used in such bids should contain only user consented ad technology providers as indicated in the bid request. Google reserves the right to filter non-compliant bids. User consented ad technology providers can be found in the Google Protocol with the BidRequest.adslot.consented_providers_settings field, and can be found as an OpenRTB extension with the BidRequest.user.ext. consented_providers_settings and BidRequest.user.ext.consent fields. See https://support.google.com/authorizedbuyers/answer/9789378 for additional information about the Google TCF v2 integration. Corresponds to the JSON property adTechnologyProviders



693
694
695
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 693

def ad_technology_providers
  @ad_technology_providers
end

#china_policy_complianceGoogle::Apis::RealtimebiddingV1::PolicyCompliance

Policy compliance of the creative for a transaction type or a region. Corresponds to the JSON property chinaPolicyCompliance



698
699
700
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 698

def china_policy_compliance
  @china_policy_compliance
end

#deals_policy_complianceGoogle::Apis::RealtimebiddingV1::PolicyCompliance

Policy compliance of the creative for a transaction type or a region. Corresponds to the JSON property dealsPolicyCompliance



703
704
705
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 703

def deals_policy_compliance
  @deals_policy_compliance
end

#detected_advertisersArray<Google::Apis::RealtimebiddingV1::AdvertiserAndBrand>

Detected advertisers and brands. Corresponds to the JSON property detectedAdvertisers



708
709
710
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 708

def detected_advertisers
  @detected_advertisers
end

#detected_attributesArray<String>

Publisher-excludable attributes that were detected for this creative. Can be used to filter the response of the creatives.list method. If the excluded_attribute field of a bid request contains one of the attributes that were declared or detected for a given creative, and a bid is submitted with that creative, the bid will be filtered before the auction. Corresponds to the JSON property detectedAttributes

Returns:

  • (Array<String>)


718
719
720
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 718

def detected_attributes
  @detected_attributes
end

#detected_categoriesArray<String>

Output only. IDs of the detected categories. The taxonomy in which the categories are expressed is specified by the detected_categories_taxonomy field. Use this in conjunction with BidRequest.bcat to avoid bidding on impressions where a given ad category is blocked, or to troubleshoot filtered bids. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property detectedCategories

Returns:

  • (Array<String>)


727
728
729
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 727

def detected_categories
  @detected_categories
end

#detected_categories_taxonomyString

Output only. The taxonomy in which the detected_categories field is expressed. Corresponds to the JSON property detectedCategoriesTaxonomy

Returns:

  • (String)


732
733
734
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 732

def detected_categories_taxonomy
  @detected_categories_taxonomy
end

#detected_click_through_urlsArray<String>

The set of detected destination URLs for the creative. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property detectedClickThroughUrls

Returns:

  • (Array<String>)


738
739
740
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 738

def detected_click_through_urls
  @detected_click_through_urls
end

#detected_domainsArray<String>

The detected domains for this creative. Corresponds to the JSON property detectedDomains

Returns:

  • (Array<String>)


743
744
745
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 743

def detected_domains
  @detected_domains
end

#detected_languagesArray<String>

The detected languages for this creative. The order is arbitrary. The codes are 2 or 5 characters and are documented at https://developers.google.com/ adwords/api/docs/appendix/languagecodes. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property detectedLanguages

Returns:

  • (Array<String>)


751
752
753
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 751

def detected_languages
  @detected_languages
end

#detected_product_categoriesArray<Fixnum>

Detected product categories, if any. See the ad-product-categories.txt file in the technical documentation for a list of IDs. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property detectedProductCategories

Returns:

  • (Array<Fixnum>)


758
759
760
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 758

def detected_product_categories
  @detected_product_categories
end

#detected_sensitive_categoriesArray<Fixnum>

Detected sensitive categories, if any. Can be used to filter the response of the creatives.list method. See the ad-sensitive-categories.txt file in the technical documentation for a list of IDs. You should use these IDs along with the excluded-sensitive-category field in the bid request to filter your bids. Corresponds to the JSON property detectedSensitiveCategories

Returns:

  • (Array<Fixnum>)


766
767
768
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 766

def detected_sensitive_categories
  @detected_sensitive_categories
end

#detected_vendor_idsArray<Fixnum>

IDs of the ad technology vendors that were detected to be used by this creative. See https://storage.googleapis.com/adx-rtb-dictionaries/vendors.txt for possible values. Can be used to filter the response of the creatives.list method. If the allowed_vendor_type field of a bid request does not contain one of the vendor type IDs that were declared or detected for a given creative, and a bid is submitted with that creative, the bid will be filtered before the auction. Corresponds to the JSON property detectedVendorIds

Returns:

  • (Array<Fixnum>)


778
779
780
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 778

def detected_vendor_ids
  @detected_vendor_ids
end

#last_status_updateString

The last time the creative status was updated. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property lastStatusUpdate

Returns:

  • (String)


784
785
786
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 784

def last_status_update
  @last_status_update
end

#network_policy_complianceGoogle::Apis::RealtimebiddingV1::PolicyCompliance

Policy compliance of the creative for a transaction type or a region. Corresponds to the JSON property networkPolicyCompliance



789
790
791
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 789

def network_policy_compliance
  @network_policy_compliance
end

#platform_policy_complianceGoogle::Apis::RealtimebiddingV1::PolicyCompliance

Policy compliance of the creative for a transaction type or a region. Corresponds to the JSON property platformPolicyCompliance



794
795
796
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 794

def platform_policy_compliance
  @platform_policy_compliance
end

#russia_policy_complianceGoogle::Apis::RealtimebiddingV1::PolicyCompliance

Policy compliance of the creative for a transaction type or a region. Corresponds to the JSON property russiaPolicyCompliance



799
800
801
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 799

def russia_policy_compliance
  @russia_policy_compliance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 806

def update!(**args)
  @ad_technology_providers = args[:ad_technology_providers] if args.key?(:ad_technology_providers)
  @china_policy_compliance = args[:china_policy_compliance] if args.key?(:china_policy_compliance)
  @deals_policy_compliance = args[:deals_policy_compliance] if args.key?(:deals_policy_compliance)
  @detected_advertisers = args[:detected_advertisers] if args.key?(:detected_advertisers)
  @detected_attributes = args[:detected_attributes] if args.key?(:detected_attributes)
  @detected_categories = args[:detected_categories] if args.key?(:detected_categories)
  @detected_categories_taxonomy = args[:detected_categories_taxonomy] if args.key?(:detected_categories_taxonomy)
  @detected_click_through_urls = args[:detected_click_through_urls] if args.key?(:detected_click_through_urls)
  @detected_domains = args[:detected_domains] if args.key?(:detected_domains)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @detected_product_categories = args[:detected_product_categories] if args.key?(:detected_product_categories)
  @detected_sensitive_categories = args[:detected_sensitive_categories] if args.key?(:detected_sensitive_categories)
  @detected_vendor_ids = args[:detected_vendor_ids] if args.key?(:detected_vendor_ids)
  @last_status_update = args[:last_status_update] if args.key?(:last_status_update)
  @network_policy_compliance = args[:network_policy_compliance] if args.key?(:network_policy_compliance)
  @platform_policy_compliance = args[:platform_policy_compliance] if args.key?(:platform_policy_compliance)
  @russia_policy_compliance = args[:russia_policy_compliance] if args.key?(:russia_policy_compliance)
end