Class: Google::Apis::RealtimebiddingV1::HtmlContent
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::HtmlContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
HTML content for a creative.
Instance Attribute Summary collapse
-
#height ⇒ Fixnum
The height of the HTML snippet in pixels.
-
#snippet ⇒ String
The HTML snippet that displays the ad when inserted in the web page.
-
#width ⇒ Fixnum
The width of the HTML snippet in pixels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HtmlContent
constructor
A new instance of HtmlContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HtmlContent
Returns a new instance of HtmlContent.
1168 1169 1170 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#height ⇒ Fixnum
The height of the HTML snippet in pixels. Can be used to filter the response
of the creatives.list method.
Corresponds to the JSON property height
1155 1156 1157 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1155 def height @height end |
#snippet ⇒ String
The HTML snippet that displays the ad when inserted in the web page.
Corresponds to the JSON property snippet
1160 1161 1162 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1160 def snippet @snippet end |
#width ⇒ Fixnum
The width of the HTML snippet in pixels. Can be used to filter the response of
the creatives.list method.
Corresponds to the JSON property width
1166 1167 1168 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1166 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1173 1174 1175 1176 1177 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1173 def update!(**args) @height = args[:height] if args.key?(:height) @snippet = args[:snippet] if args.key?(:snippet) @width = args[:width] if args.key?(:width) end |