Class: Google::Apis::RealtimebiddingV1::ListBiddersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

A response containing bidders.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBiddersResponse

Returns a new instance of ListBiddersResponse.



1277
1278
1279
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#biddersArray<Google::Apis::RealtimebiddingV1::Bidder>

List of bidders. Corresponds to the JSON property bidders



1269
1270
1271
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1269

def bidders
  @bidders
end

#next_page_tokenString

A token which can be passed to a subsequent call to the ListBidders method to retrieve the next page of results in ListBiddersRequest.pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1275
1276
1277
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1275

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1282
1283
1284
1285
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1282

def update!(**args)
  @bidders = args[:bidders] if args.key?(:bidders)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end