Class: Google::Apis::RealtimebiddingV1::ListPublisherConnectionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

A response to a request for listing publisher connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPublisherConnectionsResponse

Returns a new instance of ListPublisherConnectionsResponse.



1410
1411
1412
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the ListPublisherConnectionsRequest.pageToken field in the subsequent call to the ListPublisherConnections method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1403
1404
1405
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1403

def next_page_token
  @next_page_token
end

#publisher_connectionsArray<Google::Apis::RealtimebiddingV1::PublisherConnection>

The list of publisher connections. Corresponds to the JSON property publisherConnections



1408
1409
1410
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1408

def publisher_connections
  @publisher_connections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1415
1416
1417
1418
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1415

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @publisher_connections = args[:publisher_connections] if args.key?(:publisher_connections)
end