Class: Google::Apis::RealtimebiddingV1::MediaFile
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::MediaFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
Information about each media file in the VAST.
Instance Attribute Summary collapse
-
#bitrate ⇒ Fixnum
Bitrate of the video file, in Kbps.
-
#mime_type ⇒ String
The MIME type of this media file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MediaFile
constructor
A new instance of MediaFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MediaFile
Returns a new instance of MediaFile.
1465 1466 1467 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bitrate ⇒ Fixnum
Bitrate of the video file, in Kbps. Can be used to filter the response of the
creatives.list method.
Corresponds to the JSON property bitrate
1457 1458 1459 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1457 def bitrate @bitrate end |
#mime_type ⇒ String
The MIME type of this media file. Can be used to filter the response of the
creatives.list method.
Corresponds to the JSON property mimeType
1463 1464 1465 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1463 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1470 1471 1472 1473 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1470 def update!(**args) @bitrate = args[:bitrate] if args.key?(:bitrate) @mime_type = args[:mime_type] if args.key?(:mime_type) end |