Class: Google::Apis::RealtimebiddingV1::NativeContent
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::NativeContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
Native content for a creative.
Instance Attribute Summary collapse
-
#advertiser_name ⇒ String
The name of the advertiser or sponsor, to be displayed in the ad creative.
-
#app_icon ⇒ Google::Apis::RealtimebiddingV1::Image
An image resource.
-
#body ⇒ String
A long description of the ad.
-
#call_to_action ⇒ String
A label for the button that the user is supposed to click.
-
#click_link_url ⇒ String
The URL that the browser/SDK will load when the user clicks the ad.
-
#click_tracking_url ⇒ String
The URL to use for click tracking.
-
#headline ⇒ String
A short title for the ad.
-
#image ⇒ Google::Apis::RealtimebiddingV1::Image
An image resource.
-
#logo ⇒ Google::Apis::RealtimebiddingV1::Image
An image resource.
-
#price_display_text ⇒ String
The price of the promoted app including currency info.
-
#star_rating ⇒ Float
The app rating in the app store.
-
#video_url ⇒ String
The URL to fetch a native video ad.
-
#video_vast_xml ⇒ String
The contents of a VAST document for a native video ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NativeContent
constructor
A new instance of NativeContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NativeContent
Returns a new instance of NativeContent.
1548 1549 1550 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_name ⇒ String
The name of the advertiser or sponsor, to be displayed in the ad creative.
Corresponds to the JSON property advertiserName
1483 1484 1485 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1483 def advertiser_name @advertiser_name end |
#app_icon ⇒ Google::Apis::RealtimebiddingV1::Image
An image resource. You may provide a larger image than was requested, so long
as the aspect ratio is preserved.
Corresponds to the JSON property appIcon
1489 1490 1491 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1489 def app_icon @app_icon end |
#body ⇒ String
A long description of the ad.
Corresponds to the JSON property body
1494 1495 1496 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1494 def body @body end |
#call_to_action ⇒ String
A label for the button that the user is supposed to click.
Corresponds to the JSON property callToAction
1499 1500 1501 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1499 def call_to_action @call_to_action end |
#click_link_url ⇒ String
The URL that the browser/SDK will load when the user clicks the ad.
Corresponds to the JSON property clickLinkUrl
1504 1505 1506 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1504 def click_link_url @click_link_url end |
#click_tracking_url ⇒ String
The URL to use for click tracking.
Corresponds to the JSON property clickTrackingUrl
1509 1510 1511 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1509 def click_tracking_url @click_tracking_url end |
#headline ⇒ String
A short title for the ad.
Corresponds to the JSON property headline
1514 1515 1516 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1514 def headline @headline end |
#image ⇒ Google::Apis::RealtimebiddingV1::Image
An image resource. You may provide a larger image than was requested, so long
as the aspect ratio is preserved.
Corresponds to the JSON property image
1520 1521 1522 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1520 def image @image end |
#logo ⇒ Google::Apis::RealtimebiddingV1::Image
An image resource. You may provide a larger image than was requested, so long
as the aspect ratio is preserved.
Corresponds to the JSON property logo
1526 1527 1528 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1526 def logo @logo end |
#price_display_text ⇒ String
The price of the promoted app including currency info.
Corresponds to the JSON property priceDisplayText
1531 1532 1533 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1531 def price_display_text @price_display_text end |
#star_rating ⇒ Float
The app rating in the app store. Must be in the range [0-5].
Corresponds to the JSON property starRating
1536 1537 1538 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1536 def @star_rating end |
#video_url ⇒ String
The URL to fetch a native video ad.
Corresponds to the JSON property videoUrl
1541 1542 1543 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1541 def video_url @video_url end |
#video_vast_xml ⇒ String
The contents of a VAST document for a native video ad.
Corresponds to the JSON property videoVastXml
1546 1547 1548 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1546 def video_vast_xml @video_vast_xml end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1553 def update!(**args) @advertiser_name = args[:advertiser_name] if args.key?(:advertiser_name) @app_icon = args[:app_icon] if args.key?(:app_icon) @body = args[:body] if args.key?(:body) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @click_link_url = args[:click_link_url] if args.key?(:click_link_url) @click_tracking_url = args[:click_tracking_url] if args.key?(:click_tracking_url) @headline = args[:headline] if args.key?(:headline) @image = args[:image] if args.key?(:image) @logo = args[:logo] if args.key?(:logo) @price_display_text = args[:price_display_text] if args.key?(:price_display_text) @star_rating = args[:star_rating] if args.key?(:star_rating) @video_url = args[:video_url] if args.key?(:video_url) @video_vast_xml = args[:video_vast_xml] if args.key?(:video_vast_xml) end |