Class: Google::Apis::RealtimebiddingV1::PolicyCompliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

Policy compliance of the creative for a transaction type or a region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyCompliance

Returns a new instance of PolicyCompliance.



1628
1629
1630
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusString

Serving status for the given transaction type (for example, open auction, deals) or region (for example, China, Russia). Can be used to filter the response of the creatives.list method. Corresponds to the JSON property status

Returns:

  • (String)


1619
1620
1621
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1619

def status
  @status
end

#topicsArray<Google::Apis::RealtimebiddingV1::PolicyTopicEntry>

Topics related to the policy compliance for this transaction type (for example, open auction, deals) or region (for example, China, Russia). Topics may be present only if status is DISAPPROVED. Corresponds to the JSON property topics



1626
1627
1628
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1626

def topics
  @topics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1633
1634
1635
1636
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1633

def update!(**args)
  @status = args[:status] if args.key?(:status)
  @topics = args[:topics] if args.key?(:topics)
end