Class: Google::Apis::RealtimebiddingV1::PolicyTopicEvidence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

Evidence associated with a policy topic entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyTopicEvidence

Returns a new instance of PolicyTopicEvidence.



1726
1727
1728
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_not_crawlableGoogle::Apis::RealtimebiddingV1::DestinationNotCrawlableEvidence

Evidence that the creative's destination URL was not crawlable by Google. Corresponds to the JSON property destinationNotCrawlable



1692
1693
1694
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1692

def destination_not_crawlable
  @destination_not_crawlable
end

#destination_not_workingGoogle::Apis::RealtimebiddingV1::DestinationNotWorkingEvidence

Evidence of the creative's destination URL not functioning properly or having been incorrectly set up. Corresponds to the JSON property destinationNotWorking



1698
1699
1700
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1698

def destination_not_working
  @destination_not_working
end

#destination_urlGoogle::Apis::RealtimebiddingV1::DestinationUrlEvidence

The full landing page URL of the destination. Corresponds to the JSON property destinationUrl



1703
1704
1705
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1703

def destination_url
  @destination_url
end

#domain_callGoogle::Apis::RealtimebiddingV1::DomainCallEvidence

Number of HTTP calls made by a creative, broken down by domain. Corresponds to the JSON property domainCall



1708
1709
1710
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1708

def domain_call
  @domain_call
end

#download_sizeGoogle::Apis::RealtimebiddingV1::DownloadSizeEvidence

Total download size and URL-level download size breakdown for resources in a creative. Corresponds to the JSON property downloadSize



1714
1715
1716
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1714

def download_size
  @download_size
end

#http_callGoogle::Apis::RealtimebiddingV1::HttpCallEvidence

HTTP calls made by a creative that resulted in policy violations. Corresponds to the JSON property httpCall



1719
1720
1721
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1719

def http_call
  @http_call
end

Evidence for HTTP cookie-related policy violations. Corresponds to the JSON property httpCookie



1724
1725
1726
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1724

def http_cookie
  @http_cookie
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1731

def update!(**args)
  @destination_not_crawlable = args[:destination_not_crawlable] if args.key?(:destination_not_crawlable)
  @destination_not_working = args[:destination_not_working] if args.key?(:destination_not_working)
  @destination_url = args[:destination_url] if args.key?(:destination_url)
  @domain_call = args[:domain_call] if args.key?(:domain_call)
  @download_size = args[:download_size] if args.key?(:download_size)
  @http_call = args[:http_call] if args.key?(:http_call)
  @http_cookie = args[:http_cookie] if args.key?(:http_cookie)
end