Class: Google::Apis::RealtimebiddingV1::PublisherConnection
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::PublisherConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
An Open Bidding exchange's connection to a publisher. This is initiated by the publisher for the bidder to review. If approved by the bidder, this means that the bidder agrees to receive bid requests from the publisher.
Instance Attribute Summary collapse
-
#bidding_state ⇒ String
Whether the publisher has been approved by the bidder.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#publisher_platform ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublisherConnection
constructor
A new instance of PublisherConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublisherConnection
Returns a new instance of PublisherConnection.
1973 1974 1975 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bidding_state ⇒ String
Whether the publisher has been approved by the bidder.
Corresponds to the JSON property biddingState
1946 1947 1948 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1946 def bidding_state @bidding_state end |
#create_time ⇒ String
Output only. The time at which the publisher initiated a connection with the
bidder (irrespective of if or when the bidder approves it). This is
subsequently updated if the publisher revokes and re-initiates the connection.
Corresponds to the JSON property createTime
1953 1954 1955 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1953 def create_time @create_time end |
#display_name ⇒ String
Output only. Publisher display name.
Corresponds to the JSON property displayName
1958 1959 1960 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1958 def display_name @display_name end |
#name ⇒ String
Output only. Name of the publisher connection. This follows the pattern
bidders/bidder/publisherConnections/publisher, wherebidder
represents the account ID of the bidder, andpublisher`is the ads.txt/app-
ads.txt publisher ID.
Corresponds to the JSON propertyname`
1966 1967 1968 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1966 def name @name end |
#publisher_platform ⇒ String
Output only. Whether the publisher is an Ad Manager or AdMob publisher.
Corresponds to the JSON property publisherPlatform
1971 1972 1973 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1971 def publisher_platform @publisher_platform end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1978 1979 1980 1981 1982 1983 1984 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1978 def update!(**args) @bidding_state = args[:bidding_state] if args.key?(:bidding_state) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @publisher_platform = args[:publisher_platform] if args.key?(:publisher_platform) end |