Class: Google::Apis::RealtimebiddingV1::RemoveTargetedSitesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

A request to stop targeting sites in a specific pretargeting configuration. The pretargeting configuration itself specifies how these sites are targeted in PretargetingConfig.webTargeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveTargetedSitesRequest

Returns a new instance of RemoveTargetedSitesRequest.



2048
2049
2050
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sitesArray<String>

A list of site URLs to stop targeting in the pretargeting configuration. These values will be removed from the list of targeted URLs in PretargetingConfig. webTargeting.values. Corresponds to the JSON property sites

Returns:

  • (Array<String>)


2046
2047
2048
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2046

def sites
  @sites
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2053
2054
2055
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2053

def update!(**args)
  @sites = args[:sites] if args.key?(:sites)
end