Class: Google::Apis::RealtimebiddingV1::HttpCookieEvidence
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::HttpCookieEvidence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
Evidence for HTTP cookie-related policy violations.
Instance Attribute Summary collapse
-
#cookie_names ⇒ Array<String>
Names of cookies that violate Google policies.
-
#max_cookie_count ⇒ Fixnum
The largest number of cookies set by a creative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpCookieEvidence
constructor
A new instance of HttpCookieEvidence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpCookieEvidence
Returns a new instance of HttpCookieEvidence.
1219 1220 1221 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cookie_names ⇒ Array<String>
Names of cookies that violate Google policies. For TOO_MANY_COOKIES policy,
this will be the cookie names of top domains with the largest number of
cookies. For other policies, this will be all the cookie names that violate
the policy.
Corresponds to the JSON property cookieNames
1209 1210 1211 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1209 def @cookie_names end |
#max_cookie_count ⇒ Fixnum
The largest number of cookies set by a creative. If this field is set,
cookie_names above will be set to the cookie names of top domains with the
largest number of cookies. This field will only be set for TOO_MANY_COOKIES
policy.
Corresponds to the JSON property maxCookieCount
1217 1218 1219 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1217 def @max_cookie_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1224 1225 1226 1227 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1224 def update!(**args) @cookie_names = args[:cookie_names] if args.key?(:cookie_names) @max_cookie_count = args[:max_cookie_count] if args.key?(:max_cookie_count) end |