Class: Google::Apis::RealtimebiddingV1::ListCreativesResponse
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::ListCreativesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
A response for listing creatives.
Instance Attribute Summary collapse
-
#creatives ⇒ Array<Google::Apis::RealtimebiddingV1::Creative>
The list of creatives.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCreativesResponse
constructor
A new instance of ListCreativesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCreativesResponse
Returns a new instance of ListCreativesResponse.
1330 1331 1332 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creatives ⇒ Array<Google::Apis::RealtimebiddingV1::Creative>
The list of creatives.
Corresponds to the JSON property creatives
1321 1322 1323 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1321 def creatives @creatives end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListCreativesRequest.pageToken field in the subsequent call to the
ListCreatives method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
1328 1329 1330 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1328 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1335 1336 1337 1338 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1335 def update!(**args) @creatives = args[:creatives] if args.key?(:creatives) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |