Class: Google::Apis::RealtimebiddingV1::PretargetingConfig
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::PretargetingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
Pretargeting config: a set of targeting dimensions applied at the pretargeting stage of the RTB funnel. These control which inventory a bidder will receive bid requests for.
Instance Attribute Summary collapse
-
#allowed_user_targeting_modes ⇒ Array<String>
Targeting modes included by this config.
-
#app_targeting ⇒ Google::Apis::RealtimebiddingV1::AppTargeting
A subset of app inventory to target.
-
#billing_id ⇒ Fixnum
Output only.
-
#display_name ⇒ String
The diplay name associated with this config.
-
#excluded_content_label_ids ⇒ Array<Fixnum>
The sensitive content category label IDs excluded in this config.
-
#geo_targeting ⇒ Google::Apis::RealtimebiddingV1::NumericTargetingDimension
Generic targeting used for targeting dimensions that contain a list of included and excluded numeric IDs used in app, user list, geo, and vertical id targeting.
-
#included_creative_dimensions ⇒ Array<Google::Apis::RealtimebiddingV1::CreativeDimensions>
Creative dimensions included by this config.
-
#included_environments ⇒ Array<String>
Environments that are being included.
-
#included_formats ⇒ Array<String>
Creative formats included by this config.
-
#included_languages ⇒ Array<String>
The languages included in this config, represented by their language code.
-
#included_mobile_operating_system_ids ⇒ Array<Fixnum>
The mobile operating systems included in this config as defined in https:// storage.googleapis.com/adx-rtb-dictionaries/mobile-os.csv Corresponds to the JSON property
includedMobileOperatingSystemIds. -
#included_platforms ⇒ Array<String>
The platforms included by this config.
-
#included_user_id_types ⇒ Array<String>
User identifier types included in this config.
-
#interstitial_targeting ⇒ String
The interstitial targeting specified for this config.
-
#invalid_geo_ids ⇒ Array<Fixnum>
Output only.
-
#maximum_qps ⇒ Fixnum
The maximum QPS threshold for this config.
-
#minimum_viewability_decile ⇒ Fixnum
The targeted minimum viewability decile, ranging in values [0, 10].
-
#name ⇒ String
Output only.
-
#publisher_targeting ⇒ Google::Apis::RealtimebiddingV1::StringTargetingDimension
Generic targeting with string values used in app, website and publisher targeting.
-
#state ⇒ String
Output only.
-
#user_list_targeting ⇒ Google::Apis::RealtimebiddingV1::NumericTargetingDimension
Generic targeting used for targeting dimensions that contain a list of included and excluded numeric IDs used in app, user list, geo, and vertical id targeting.
-
#vertical_targeting ⇒ Google::Apis::RealtimebiddingV1::NumericTargetingDimension
Generic targeting used for targeting dimensions that contain a list of included and excluded numeric IDs used in app, user list, geo, and vertical id targeting.
-
#web_targeting ⇒ Google::Apis::RealtimebiddingV1::StringTargetingDimension
Generic targeting with string values used in app, website and publisher targeting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PretargetingConfig
constructor
A new instance of PretargetingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PretargetingConfig
Returns a new instance of PretargetingConfig.
1904 1905 1906 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_user_targeting_modes ⇒ Array<String>
Targeting modes included by this config. A bid request must allow all the
specified targeting modes. An unset value allows all bid requests to be sent,
regardless of which targeting modes they allow.
Corresponds to the JSON property allowedUserTargetingModes
1753 1754 1755 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1753 def allowed_user_targeting_modes @allowed_user_targeting_modes end |
#app_targeting ⇒ Google::Apis::RealtimebiddingV1::AppTargeting
A subset of app inventory to target. Bid requests that match criteria in at
least one of the specified dimensions will be sent.
Corresponds to the JSON property appTargeting
1759 1760 1761 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1759 def app_targeting @app_targeting end |
#billing_id ⇒ Fixnum
Output only. The identifier that corresponds to this pretargeting config that
helps buyers track and attribute their spend across their own arbitrary
divisions. If a bid request matches more than one config, the buyer chooses
which billing_id to attribute each of their bids.
Corresponds to the JSON property billingId
1767 1768 1769 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1767 def billing_id @billing_id end |
#display_name ⇒ String
The diplay name associated with this config. This name must be unique among
all the pretargeting configs a bidder has.
Corresponds to the JSON property displayName
1773 1774 1775 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1773 def display_name @display_name end |
#excluded_content_label_ids ⇒ Array<Fixnum>
The sensitive content category label IDs excluded in this config. Bid requests
for inventory with any of the specified content label IDs will not be sent.
Refer to this file https://storage.googleapis.com/adx-rtb-dictionaries/content-
labels.txt for category IDs.
Corresponds to the JSON property excludedContentLabelIds
1781 1782 1783 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1781 def excluded_content_label_ids @excluded_content_label_ids end |
#geo_targeting ⇒ Google::Apis::RealtimebiddingV1::NumericTargetingDimension
Generic targeting used for targeting dimensions that contain a list of
included and excluded numeric IDs used in app, user list, geo, and vertical id
targeting.
Corresponds to the JSON property geoTargeting
1788 1789 1790 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1788 def geo_targeting @geo_targeting end |
#included_creative_dimensions ⇒ Array<Google::Apis::RealtimebiddingV1::CreativeDimensions>
Creative dimensions included by this config. Only bid requests eligible for at
least one of the specified creative dimensions will be sent. An unset value
allows all bid requests to be sent, regardless of creative dimension.
Corresponds to the JSON property includedCreativeDimensions
1795 1796 1797 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1795 def included_creative_dimensions @included_creative_dimensions end |
#included_environments ⇒ Array<String>
Environments that are being included. Bid requests will not be sent for a
given environment if it is not included. Further restrictions can be applied
to included environments to target only a subset of its inventory. An unset
value includes all environments.
Corresponds to the JSON property includedEnvironments
1803 1804 1805 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1803 def included_environments @included_environments end |
#included_formats ⇒ Array<String>
Creative formats included by this config. Only bid requests eligible for at
least one of the specified creative formats will be sent. An unset value will
allow all bid requests to be sent, regardless of format.
Corresponds to the JSON property includedFormats
1810 1811 1812 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1810 def included_formats @included_formats end |
#included_languages ⇒ Array<String>
The languages included in this config, represented by their language code. See
https://developers.google.com/adwords/api/docs/appendix/languagecodes.
Corresponds to the JSON property includedLanguages
1816 1817 1818 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1816 def included_languages @included_languages end |
#included_mobile_operating_system_ids ⇒ Array<Fixnum>
The mobile operating systems included in this config as defined in https://
storage.googleapis.com/adx-rtb-dictionaries/mobile-os.csv
Corresponds to the JSON property includedMobileOperatingSystemIds
1822 1823 1824 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1822 def @included_mobile_operating_system_ids end |
#included_platforms ⇒ Array<String>
The platforms included by this config. Bid requests for devices with the
specified platform types will be sent. An unset value allows all bid requests
to be sent, regardless of platform.
Corresponds to the JSON property includedPlatforms
1829 1830 1831 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1829 def included_platforms @included_platforms end |
#included_user_id_types ⇒ Array<String>
User identifier types included in this config. At least one of the user
identifier types specified in this list must be available for the bid request
to be sent.
Corresponds to the JSON property includedUserIdTypes
1836 1837 1838 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1836 def included_user_id_types @included_user_id_types end |
#interstitial_targeting ⇒ String
The interstitial targeting specified for this config. The unset value will
allow bid requests to be sent regardless of whether they are for interstitials
or not.
Corresponds to the JSON property interstitialTargeting
1843 1844 1845 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1843 def interstitial_targeting @interstitial_targeting end |
#invalid_geo_ids ⇒ Array<Fixnum>
Output only. Existing included or excluded geos that are invalid. Previously
targeted geos may become invalid due to privacy restrictions.
Corresponds to the JSON property invalidGeoIds
1849 1850 1851 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1849 def invalid_geo_ids @invalid_geo_ids end |
#maximum_qps ⇒ Fixnum
The maximum QPS threshold for this config. The bidder should receive no more
than this number of bid requests matching this config per second across all
their bidding endpoints among all trading locations. Further information
available at https://developers.google.com/authorized-buyers/rtb/peer-guide
Corresponds to the JSON property maximumQps
1857 1858 1859 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1857 def maximum_qps @maximum_qps end |
#minimum_viewability_decile ⇒ Fixnum
The targeted minimum viewability decile, ranging in values [0, 10]. A value of
5 means that the config will only match adslots for which we predict at least
50% viewability. Values > 10 will be rounded down to 10. An unset value or a
value of 0 indicates that bid requests will be sent regardless of viewability.
Corresponds to the JSON property minimumViewabilityDecile
1865 1866 1867 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1865 def minimum_viewability_decile @minimum_viewability_decile end |
#name ⇒ String
Output only. Name of the pretargeting config that must follow the pattern
bidders/bidder_account_id/pretargetingConfigs/config_id`
Corresponds to the JSON propertyname`
1871 1872 1873 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1871 def name @name end |
#publisher_targeting ⇒ Google::Apis::RealtimebiddingV1::StringTargetingDimension
Generic targeting with string values used in app, website and publisher
targeting.
Corresponds to the JSON property publisherTargeting
1877 1878 1879 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1877 def publisher_targeting @publisher_targeting end |
#state ⇒ String
Output only. The state of this pretargeting config.
Corresponds to the JSON property state
1882 1883 1884 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1882 def state @state end |
#user_list_targeting ⇒ Google::Apis::RealtimebiddingV1::NumericTargetingDimension
Generic targeting used for targeting dimensions that contain a list of
included and excluded numeric IDs used in app, user list, geo, and vertical id
targeting.
Corresponds to the JSON property userListTargeting
1889 1890 1891 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1889 def user_list_targeting @user_list_targeting end |
#vertical_targeting ⇒ Google::Apis::RealtimebiddingV1::NumericTargetingDimension
Generic targeting used for targeting dimensions that contain a list of
included and excluded numeric IDs used in app, user list, geo, and vertical id
targeting.
Corresponds to the JSON property verticalTargeting
1896 1897 1898 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1896 def vertical_targeting @vertical_targeting end |
#web_targeting ⇒ Google::Apis::RealtimebiddingV1::StringTargetingDimension
Generic targeting with string values used in app, website and publisher
targeting.
Corresponds to the JSON property webTargeting
1902 1903 1904 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1902 def web_targeting @web_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1909 def update!(**args) @allowed_user_targeting_modes = args[:allowed_user_targeting_modes] if args.key?(:allowed_user_targeting_modes) @app_targeting = args[:app_targeting] if args.key?(:app_targeting) @billing_id = args[:billing_id] if args.key?(:billing_id) @display_name = args[:display_name] if args.key?(:display_name) @excluded_content_label_ids = args[:excluded_content_label_ids] if args.key?(:excluded_content_label_ids) @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting) @included_creative_dimensions = args[:included_creative_dimensions] if args.key?(:included_creative_dimensions) @included_environments = args[:included_environments] if args.key?(:included_environments) @included_formats = args[:included_formats] if args.key?(:included_formats) @included_languages = args[:included_languages] if args.key?(:included_languages) @included_mobile_operating_system_ids = args[:included_mobile_operating_system_ids] if args.key?(:included_mobile_operating_system_ids) @included_platforms = args[:included_platforms] if args.key?(:included_platforms) @included_user_id_types = args[:included_user_id_types] if args.key?(:included_user_id_types) @interstitial_targeting = args[:interstitial_targeting] if args.key?(:interstitial_targeting) @invalid_geo_ids = args[:invalid_geo_ids] if args.key?(:invalid_geo_ids) @maximum_qps = args[:maximum_qps] if args.key?(:maximum_qps) @minimum_viewability_decile = args[:minimum_viewability_decile] if args.key?(:minimum_viewability_decile) @name = args[:name] if args.key?(:name) @publisher_targeting = args[:publisher_targeting] if args.key?(:publisher_targeting) @state = args[:state] if args.key?(:state) @user_list_targeting = args[:user_list_targeting] if args.key?(:user_list_targeting) @vertical_targeting = args[:vertical_targeting] if args.key?(:vertical_targeting) @web_targeting = args[:web_targeting] if args.key?(:web_targeting) end |