Class: Google::Apis::RealtimebiddingV1::PublisherConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

An Open Bidding exchange's connection to a publisher. This is initiated by the publisher for the bidder to review. If approved by the bidder, this means that the bidder agrees to receive bid requests from the publisher.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublisherConnection

Returns a new instance of PublisherConnection.



1972
1973
1974
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bidding_stateString

Whether the publisher has been approved by the bidder. Corresponds to the JSON property biddingState

Returns:

  • (String)


1945
1946
1947
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1945

def bidding_state
  @bidding_state
end

#create_timeString

Output only. The time at which the publisher initiated a connection with the bidder (irrespective of if or when the bidder approves it). This is subsequently updated if the publisher revokes and re-initiates the connection. Corresponds to the JSON property createTime

Returns:

  • (String)


1952
1953
1954
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1952

def create_time
  @create_time
end

#display_nameString

Output only. Publisher display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1957
1958
1959
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1957

def display_name
  @display_name
end

#nameString

Output only. Name of the publisher connection. This follows the pattern bidders/bidder/publisherConnections/publisher, wherebidder represents the account ID of the bidder, andpublisher`is the ads.txt/app- ads.txt publisher ID. Corresponds to the JSON propertyname`

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1965

def name
  @name
end

#publisher_platformString

Output only. Whether the publisher is an Ad Manager or AdMob publisher. Corresponds to the JSON property publisherPlatform

Returns:

  • (String)


1970
1971
1972
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1970

def publisher_platform
  @publisher_platform
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1977
1978
1979
1980
1981
1982
1983
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1977

def update!(**args)
  @bidding_state = args[:bidding_state] if args.key?(:bidding_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @publisher_platform = args[:publisher_platform] if args.key?(:publisher_platform)
end