Class: Google::Apis::RealtimebiddingV1::RemoveTargetedAppsRequest
- Inherits:
-
Object
- Object
- Google::Apis::RealtimebiddingV1::RemoveTargetedAppsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb
Overview
A request to stop targeting the provided apps in a specific pretargeting configuration. The pretargeting configuration itself specifies how these apps are targeted. in PretargetingConfig.appTargeting.mobileAppTargeting.
Instance Attribute Summary collapse
-
#app_ids ⇒ Array<String>
A list of app IDs to stop targeting in the pretargeting configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveTargetedAppsRequest
constructor
A new instance of RemoveTargetedAppsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveTargetedAppsRequest
Returns a new instance of RemoveTargetedAppsRequest.
2000 2001 2002 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_ids ⇒ Array<String>
A list of app IDs to stop targeting in the pretargeting configuration. These
values will be removed from the list of targeted app IDs in PretargetingConfig.
appTargeting.mobileAppTargeting.values.
Corresponds to the JSON property appIds
1998 1999 2000 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1998 def app_ids @app_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2005 2006 2007 |
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2005 def update!(**args) @app_ids = args[:app_ids] if args.key?(:app_ids) end |