Class: Google::Apis::RealtimebiddingV1::RemoveTargetedAppsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

A request to stop targeting the provided apps in a specific pretargeting configuration. The pretargeting configuration itself specifies how these apps are targeted. in PretargetingConfig.appTargeting.mobileAppTargeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveTargetedAppsRequest

Returns a new instance of RemoveTargetedAppsRequest.



1999
2000
2001
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idsArray<String>

A list of app IDs to stop targeting in the pretargeting configuration. These values will be removed from the list of targeted app IDs in PretargetingConfig. appTargeting.mobileAppTargeting.values. Corresponds to the JSON property appIds

Returns:

  • (Array<String>)


1997
1998
1999
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 1997

def app_ids
  @app_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2004
2005
2006
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2004

def update!(**args)
  @app_ids = args[:app_ids] if args.key?(:app_ids)
end