Class: Google::Apis::RealtimebiddingV1::RemoveTargetedPublishersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

A request to stop targeting publishers in a specific configuration. The pretargeting configuration itself specifies how these publishers are targeted in PretargetingConfig.publisherTargeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveTargetedPublishersRequest

Returns a new instance of RemoveTargetedPublishersRequest.



2024
2025
2026
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#publisher_idsArray<String>

A list of publisher IDs to stop targeting in the pretargeting configuration. These values will be removed from the list of targeted publisher IDs in PretargetingConfig.publisherTargeting.values. Publishers are identified by their publisher ID from ads.txt / app-ads.txt. See https://iabtechlab.com/ads- txt/ and https://iabtechlab.com/app-ads-txt/ for more details. Corresponds to the JSON property publisherIds

Returns:

  • (Array<String>)


2022
2023
2024
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2022

def publisher_ids
  @publisher_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2029
2030
2031
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2029

def update!(**args)
  @publisher_ids = args[:publisher_ids] if args.key?(:publisher_ids)
end