Class: Google::Apis::RealtimebiddingV1::VideoMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

Video metadata for a creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoMetadata

Returns a new instance of VideoMetadata.



2316
2317
2318
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The duration of the ad. Can be used to filter the response of the creatives. list method. Corresponds to the JSON property duration

Returns:

  • (String)


2279
2280
2281
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2279

def duration
  @duration
end

#is_valid_vastBoolean Also known as: is_valid_vast?

Is this a valid VAST ad? Can be used to filter the response of the creatives. list method. Corresponds to the JSON property isValidVast

Returns:

  • (Boolean)


2285
2286
2287
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2285

def is_valid_vast
  @is_valid_vast
end

#is_vpaidBoolean Also known as: is_vpaid?

Is this a VPAID ad? Can be used to filter the response of the creatives.list method. Corresponds to the JSON property isVpaid

Returns:

  • (Boolean)


2292
2293
2294
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2292

def is_vpaid
  @is_vpaid
end

#media_filesArray<Google::Apis::RealtimebiddingV1::MediaFile>

The list of all media files declared in the VAST. If there are multiple VASTs in a wrapper chain, this includes the media files from the deepest one in the chain. Corresponds to the JSON property mediaFiles



2300
2301
2302
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2300

def media_files
  @media_files
end

#skip_offsetString

The minimum duration that the user has to watch before being able to skip this ad. If the field is not set, the ad is not skippable. If the field is set, the ad is skippable. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property skipOffset

Returns:

  • (String)


2308
2309
2310
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2308

def skip_offset
  @skip_offset
end

#vast_versionString

The maximum VAST version across all wrapped VAST documents. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property vastVersion

Returns:

  • (String)


2314
2315
2316
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2314

def vast_version
  @vast_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2321
2322
2323
2324
2325
2326
2327
2328
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2321

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @is_valid_vast = args[:is_valid_vast] if args.key?(:is_valid_vast)
  @is_vpaid = args[:is_vpaid] if args.key?(:is_vpaid)
  @media_files = args[:media_files] if args.key?(:media_files)
  @skip_offset = args[:skip_offset] if args.key?(:skip_offset)
  @vast_version = args[:vast_version] if args.key?(:vast_version)
end