Class: Google::Apis::RealtimebiddingV1::WatchCreativesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/realtimebidding_v1/classes.rb,
lib/google/apis/realtimebidding_v1/representations.rb,
lib/google/apis/realtimebidding_v1/representations.rb

Overview

A response for the request to receive push notification when a bidder's creatives change status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WatchCreativesResponse

Returns a new instance of WatchCreativesResponse.



2367
2368
2369
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#subscriptionString

The Pub/Sub subscription that can be used to pull creative status notifications. This would be of the format projects/project_id/ subscriptions/subscription_id`. Subscription is created with pull delivery. All service accounts belonging to the bidder will have read access to this subscription. Subscriptions that are inactive for more than 90 days will be disabled. Use watchCreatives to re-enable the subscription. Corresponds to the JSON propertysubscription`

Returns:

  • (String)


2358
2359
2360
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2358

def subscription
  @subscription
end

#topicString

The Pub/Sub topic that will be used to publish creative serving status notifications. This would be of the format projects/project_id/topics/ topic_id`. Corresponds to the JSON propertytopic`

Returns:

  • (String)


2365
2366
2367
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2365

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2372
2373
2374
2375
# File 'lib/google/apis/realtimebidding_v1/classes.rb', line 2372

def update!(**args)
  @subscription = args[:subscription] if args.key?(:subscription)
  @topic = args[:topic] if args.key?(:topic)
end